@@ -36,8 +36,14 @@ F<svnadmin> command is expected to be in the same directory as F<svn>.
 
 =head1 METHODS
 
+=over 4
+
+=item build
+
 =cut
 
+
+
 sub build {
     my $self = shift;
     $self->strip_repository
@@ -45,8 +51,6 @@ sub build {
     $self->SUPER::build(@_);
 }
 
-=over 4
-
 =item initialize
 
 initialize a project.
@@ -249,8 +253,12 @@ sub check_repository {
         # $err like
         # file:///tmp/svn/foo:  (Not a valid URL)
         # usually means foo doesn't exist, which is valid for create
-        return 1 if $info || $err && $err =~ m{^\Q$repo\E:}m;
-
+        if ($info) {
+            return 1 if $args{force} || $info =~ /Revision: 0/;
+            $self->log->fatal("$repo has commits already");
+            return;
+        }
+        return 1 if $err && $err =~ m{^\Q$repo\E:}m;
     }
     else {
         return $self->SUPER::check_repository(@_);
